import pytest

from ..fields import MongoengineConnectionField
from .types import ArticleNode


def test_field_args():
    field = MongoengineConnectionField(ArticleNode)

    field_args = ['id', 'headline', 'pub_date']
    assert set(field.field_args.keys()) == set(field_args)

    reference_args = ['editor', 'reporter']
    assert set(field.reference_args.keys()) == set(reference_args)

    default_args = ['after', 'last', 'first', 'before']
    args = field_args + reference_args + default_args
    assert set(field.args) == set(args)



import pytest
from mongoengine import Document


from ..utils import (
    get_model_fields, is_valid_mongoengine_model
)
from .models import Article, Reporter, Child


def test_get_model_fields_no_duplication():
    reporter_fields = get_model_fields(Reporter)
    reporter_name_set = set(reporter_fields)
    assert len(reporter_fields) == len(reporter_name_set)


def test_get_model_relation_fields():
    article_fields = get_model_fields(Article)
    assert all(field in set(article_fields) for field in ['editor', 'reporter'])


def test_get_base_model_fields():
    child_fields = get_model_fields(Child)
    assert all(field in set(child_fields) for field in ['bar', 'baz'])

def test_is_valid_mongoengine_mode():
    assert is_valid_mongoengine_model(Reporter)

